{
  description = "hostapps";
  # nixConfig.bash-prompt-suffix = "develop";
  inputs = {
    nixpkgs = {
      url = "github:nixos/nixpkgs/nixos-unstable";
    };
  };
  outputs = { self, nixpkgs }@input:
    let
      version = self.lastModifiedDate;
      supportedSystems = [ "x86_64-linux" "aarch64-linux" ];
      forAllSystems = nixpkgs.lib.genAttrs supportedSystems;
      nixpkgsFor = forAllSystems (system: import nixpkgs { inherit system; });
    in
    {
      packages = forAllSystems
        (
          system:
          let
            pkgs = nixpkgsFor.${system};
          in
          {
            hostapps = pkgs.poetry2nix.mkPoetryApplication {
              python = pkgs.python310;
              projectDir = ./.;
              propagatedBuildInputs = [
                pkgs.openssh
              ];
            };
          }
        );
      defaultPackage = forAllSystems (system: self.packages.${system}.hostapps);
      devShells = forAllSystems
        (
          system:
          let
            pkgs = nixpkgsFor.${system};
            python = pkgs.python310.withPackages (
              ps: with ps; [
                poetry
                black
                flake8
              ]
            );
          in
          {
            default =
              pkgs.mkShell {
                buildInputs = with pkgs; [
                  python
                  openssh
                ];
                shellHook = ''
                  export POETRY_VIRTUALENVS_IN_PROJECT=true
                '';
              };
          }
        );
    };
}
